==> hs-dev-helper-0.0.1.tgz: package/js-toolkit/fragments/video-block.js <==
export default (function(){
    return {
        debug: false,
        containers: [],

        init: function(selector){
            this.log('Initializing video block..');

            let [els] = this.containers[selector] || [];

            els.forEach((el)=>{
                let vjs = el.querySelector('.video-js');
                this.log('Found video-js element: ', vjs);
                let url = vjs.getAttribute('data-url');
                let type = vjs.getAttribute('data-type');

                videojs(vjs, {
                    sources: [{
                      src: url,
                      type: type
                    }]
                });
            });
        },

        initIfExists: function(selector){
            this.log('Initializing if exists..');

            let els = document.querySelectorAll(selector) || [];

            if (els.length) {
                this.log('Container exists..');

                this.containers[selector] = [els];
                this.loadStylesheet();

                if (typeof videojs == 'function') { 
                    this.log('Videojs exists as function..');
                    this.init(selector);
                }
                else{
                    this.log('Videojs not found! Loading from cdn..');
                    this.loadJSLibs(selector);
                }
            }
            else {
                this.log(`Container with selector ${selector} not found!`);
            }
        },

        log: function(...args){
            if (this.debug) {
                console.log(args);
            } 
        },

        loadStylesheet(){
            let link = document.createElement("link");
            link.type = "text/css";
            link.rel = "stylesheet";
            link.href = 'https://vjs.zencdn.net/7.8.4/video-js.css';
            document.head.appendChild(link);
        },

        loadJSLibs(selector) {
            const script = document.createElement('script');
            script.src = 'https://vjs.zencdn.net/7.8.4/video.js';
            document.body.appendChild(script);

            const yt = document.createElement('script');
            yt.src = 'https://cdnjs.cloudflare.com/ajax/libs/videojs-youtube/2.6.1/Youtube.min.js';
            
            script.onload = ()=>{
                this.log('Videojs loaded from cdn..');
                this.log('Loading videojs-youtube..');

                document.body.appendChild(yt);
                yt.onload = ()=>{
                    this.log('videojs-youtube loaded..');
                    this.init(selector);
                }
            };
        }
    }
})();

==> hs-dev-helper-0.1.9.tgz: package/js-toolkit/fragments/video-block.js <==
export default (function(){
	return {

        debug: false,
        containers: [],

        init: function(selector){
            this.log('Initializing video block..');

            let [els] = this.containers[selector] || [];

            els.forEach((el)=>{
                let vjs = el.querySelector('.video-js');
                this.log('Found video-js element: ', vjs);
                let url = vjs.getAttribute('data-url');
                let type = vjs.getAttribute('data-type');

                videojs(vjs, {
					fluid: true,
					fill: true,
					responsive: true,
                    sources: [{
                      src: url,
                      type: type
                    }]
                });
            });
        },

        initIfExists: function(selector){
            this.log('Initializing if exists..');

            let els = document.querySelectorAll(selector) || [];

            if (els.length) {
                this.log('Container exists..');

                this.containers[selector] = [els];
                this.loadStylesheet();

                if (typeof videojs == 'function') { 
                    this.log('Videojs exists as function..');
                    this.init(selector);
                }
                else{
                    this.log('Videojs not found! Loading from cdn..');
                    this.loadJSLibs(selector);
                }
            }
            else {
                this.log(`Container with selector ${selector} not found!`);
            }
        },

        log: function(...args){
            if (this.debug) {
                console.log(args);
            } 
        },

        loadStylesheet(){
            let link = document.createElement("link");
            link.type = "text/css";
            link.rel = "stylesheet";
            link.href = 'https://vjs.zencdn.net/8.3.0/video-js.css';
            document.head.appendChild(link);
        },

        loadJSLibs(selector) {
            const script = document.createElement('script');
            script.src = 'https://vjs.zencdn.net/8.3.0/video.min.js';
            document.body.appendChild(script);

            const yt = document.createElement('script');
            yt.src = 'https://cdnjs.cloudflare.com/ajax/libs/videojs-youtube/3.0.1/Youtube.min.js';
            
            script.onload = ()=>{
                this.log('Videojs loaded from cdn..');
                this.log('Loading videojs-youtube..');

                document.body.appendChild(yt);
                yt.onload = ()=>{
                    this.log('videojs-youtube loaded..');
                    this.init(selector);
                }
            };
        }
    }
})();
